# Collection of examples from Chapter 2

source("ex2.01.R")
source("ex2.02.R")
source("ex2.03.R")
source("ex2.04.R")
source("ex2.05.R")
source("ex2.06.R")
source("ex2.07.R")
source("ex2.08.R")
source("ex2.09.R")
source("ex2.10.R")
source("ex2.11.R")
source("ex2.12.R")
source("ex2.13.R")
source("ex2.14.R")
source("ex2.15.R")
source("ex2.16.R")
source("ex2.17.R")
source("ex2.18.R")



