# Collection of examples from Chapter 1

source("ex1.01.R")
source("ex1.02.R")
source("ex1.03.R")
source("ex1.04.R")
source("ex1.05.R")
source("ex1.06.R")
source("ex1.07.R")
source("ex1.08.R")
source("ex1.09.R")
source("ex1.10.R")
source("ex1.11.R")
source("ex1.12.R")
source("ex1.13.R")
source("ex1.14.R")
source("ex1.15.R")


