# Collection of examples from Chapter 3

source("ex3.01.R")
source("ex3.02.R")
source("ex3.03.R")
source("ex3.04.R")
source("ex3.05.R")
source("ex3.06.R")
source("ex3.07.R")
source("ex3.08.R")
source("ex3.09.R")
source("ex3.10.R")
source("ex3.11.R")
source("ex3.12.R")
source("ex3.13.R")
source("ex3.14.R")
source("ex3.15.R")
source("ex3.16.R")



